// Copyright 2007 Michiel Helvensteijn
// 
// This file is part of Timekeeper.
// 
// Timekeeper is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// Timekeeper is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with Timekeeper; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

#include "activity.h"

Activity::Activity() {
} // intentionally empty

Activity::Activity(const QString & category, const QDateTime & start, const QDateTime & end, const QString & note) : _category(category), _start(start), _end(end), _note(note) {
} // intentionally empty

const QString & Activity::getCategory() const {
	return _category;
}

const QDateTime & Activity::getStart() const {
	return _start;
}

const QDateTime & Activity::getEnd() const {
	return _end;
}

QTime Activity::getDuration() const {
	return QTime(0, 0, 0).addSecs(_start.secsTo(_end));
}

const QString & Activity::getNote() const {
	return _note;
}

void Activity::setCategory(const QString & category) {
	_category = category;
}

void Activity::setStart(const QDateTime & start) {
	_start = start;
	
	if (_start > _end) {
		_end = _start;
	}
}

void Activity::setEnd(const QDateTime & end) {
	_end = end;
	
	if (_start > _end) {
		_start = _end;
	}
}

void Activity::setDuration(QTime duration) {
	_end = _start.addSecs(QTime(0, 0, 0).secsTo(duration));
}

void Activity::setNote(const QString & note) {
	_note = note;
}
