// Copyright 2007 Michiel Helvensteijn
// 
// This file is part of Timekeeper.
// 
// Timekeeper is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// Timekeeper is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with Timekeeper; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

#ifndef EXCEPTIONS_H
#define EXCEPTIONS_H

#include <QString>

/**
 * The base exception class.
 * Every exception should inherit this.
 * 
 * @author Michiel Helvensteijn
 * @date 28-12-2006
 */
class Exception {
	public:
		
		Exception(QString defaultMessage) : _message(defaultMessage) {
		} // intentionally empty
		
		QString message() const {
			return _message;
		}
		
		void setMessage(QString message) {
			_message = message;
		}
	
	private:
		
		QString _message;
};

/**
 * Defines a new exception class with class-name \a n and default description \a m.
 * 
 * @param n The class-name of the new exception.
 * @param m The default description of the exception.
 */
#define EXCEPTION(n ,m)                                                  \
	class n : public Exception {                                         \
		public:                                                          \
			                                                             \
			n (QString defaultMessage = m) : Exception(defaultMessage) { \
			}                                                            \
	}

/// Thrown if an activity was already running
EXCEPTION(ActivityIsRunning, "An activity was already running.");

/// Thrown if there was no activity running
EXCEPTION(NoActivityRunning, "There was no activity running.");

/// Thrown if that file does not exist
EXCEPTION(NoSuchFile, "That file does not exist.");

/// Thrown if you have the wrong permissions
EXCEPTION(NoPermission, "You have the wrong permissions.");

/// Thrown if The specified file is not a valid timekeeper log
EXCEPTION(InvalidFile, "The specified file is not a valid timekeeper log.");

/// Thrown if an unknown error occurred
EXCEPTION(UnknownError, "An unknown error occurred.");

/// Thrown if there is an error in the template
EXCEPTION(TemplateError, "There is an error in the template.");

/// Thrown if your requested only item is not the only item
EXCEPTION(NotTheOnlyOne, "Your requested only item is not the only item.");

#endif // EXCEPTIONS_H
